#include <QApplication>
#include <QWidget>
#include <QMainWindow>
#include <QGraphicsScene>
#include <QGraphicsView>
#include <QGraphicsPathItem>
#include <QGraphicsEllipseItem>
#include <QPen>
#include <QShortcut>
#include <QStyle>

#include <QDebug>
#include <QSysInfo>

#include <algorithm>
#include <iostream>

// 1.2

static QString title()
{
    return QLatin1String(QT_VERSION_STR) + QLatin1Char(' ') + QGuiApplication::platformName()
        + QLatin1Char(' ') + QApplication::style()->objectName();
}

int main(int argc, char *argv[])
{
    QStringList args;
    std::copy(argv + 1, argv + argc, std::back_inserter(args));

    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);

    QApplication app(argc, argv);

    QMainWindow w;
    QString t = title();
    qDebug().noquote() << t << args;
    w.setWindowTitle(t);

    auto scene = new QGraphicsScene();

    auto view = new QGraphicsView(scene);

    view->scale(10, 10);

    view->setRenderHints(QPainter::Antialiasing);

    w.setCentralWidget(view);

    QPen pen(QBrush(QColor(0, 0, 0, 255)), 1);

    pen.setCosmetic(true);

    QBrush brush(QColor(0, 0, 255, 255));

    auto ellipse1 = new QGraphicsEllipseItem(0, 0, 20, 20);

    ellipse1->setStartAngle(0 * 16);

    ellipse1->setSpanAngle(180 * 16);

    auto ellipse2 = new QGraphicsEllipseItem(0, 20, 20, 20);

    ellipse2->setStartAngle(0 * 16);

    ellipse2->setSpanAngle(360 * 16);

    auto painter_path1 = ellipse1->shape().simplified();
    auto painter_path2 = ellipse2->shape().simplified();

    auto path_item1 = new QGraphicsPathItem(painter_path1);

    path_item1->setPen(pen);

    path_item1->setBrush(brush);

    scene->addItem(path_item1);

    auto path_item2 = new QGraphicsPathItem(painter_path2);

    path_item2->setPen(pen);

    path_item2->setBrush(brush);

    scene->addItem(path_item2);

    new QShortcut(Qt::CTRL + Qt::Key_Q, &w, SLOT(close()));
    w.show();
    return QCoreApplication::exec();
}
